.. _pecan_templating:

:mod:`pecan.templating` -- Pecan Templating
===========================================

The :mod:`pecan.templating` module includes support for a variety of
templating engines, plus the ability to create your own template
engines.

.. automodule:: pecan.templating
  :members:
  :show-inheritance: